@@ -48,13 +48,17 @@ HBASE_BACKUP_VERSION = (
 # create-cluster options help text
 
 CREATE_CLUSTER_DESCRIPTION = (
-    'Creates an Amazon EMR cluster with the specified configurations.\n'
-    '\nQuick start:\n'
-    '\naws emr create-cluster --release-label <release-label>'
-    ' --instance-type <instance-type> --instance-count <instance-count>\n'
-    '\nValues for the following can be set in the AWS CLI'
-    ' config file using the "aws configure set" command: --service-role, --log-uri,'
-    ' and InstanceProfile and KeyName arguments under --ec2-attributes.')
+    'Creates an Amazon EMR cluster with the specified configurations.')
+
+DESCRIBE_CLUSTER_DESCRIPTION = (
+    'Provides  cluster-level details including status, hardware '
+    'and software configuration, VPC settings, bootstrap '
+    'actions, instance groups and so on. '
+    'Permissions needed for describe-cluster include '
+    'elasticmapreduce:ListBootstrapActions, '
+    'elasticmapreduce:ListInstanceFleets, '
+    'elasticmapreduce:DescribeCluster, '
+    'and elasticmapreduce:ListInstanceGroups.')
 
 CLUSTER_NAME = (
     '<p>The name of the cluster. If not provided, the default is "Development Cluster".</p>')
@@ -113,6 +117,11 @@ RELEASE_LABEL = (
     ' and later. Use <code>--ami-version</code> for earlier versions.'
     ' You cannot specify both a release label and AMI version.</p>')
 
+OS_RELEASE_LABEL = (
+    '<p>Specifies a particular Amazon Linux release for all nodes in a cluster'
+    ' launch request. If a release is not specified, EMR uses the latest validated' 
+    ' Amazon Linux release for cluster launch.</p>')
+
 CONFIGURATIONS = (
     '<p>Specifies a JSON file that contains configuration classifications,'
     ' which you can use to customize applications that Amazon EMR installs'
@@ -205,7 +214,8 @@ INSTANCE_COUNT = (
     ' are used for the core node type.</p>')
 
 ADDITIONAL_INFO = (
-    '<p>Specifies additional information during cluster creation.</p>')
+    '<p>Specifies additional information during cluster creation. To set development mode when starting your EMR cluster,'
+    ' set this parameter to <code>{"clusterType":"development"}</code>.</p>')
 
 EC2_ATTRIBUTES = (
     '<p>Configures cluster and Amazon EC2 instance configurations. Accepts'
@@ -260,21 +270,21 @@ SCALE_DOWN_BEHAVIOR = (
     ' terminate EC2 instances at the instance-hour boundary, regardless of when'
     ' the request to terminate was submitted.</li>'
 )
+
 VISIBILITY = (
-    '<p>Specifies whether the cluster is visible to all IAM users of'
-    ' the AWS account associated with the cluster. If set to'
-    ' <code>--visible-to-all-users</code>, all IAM users of that AWS account'
-    ' can view it. If they have the proper policy permissions set, they can '
-    ' also manage the cluster. If it is set to <code>--no-visible-to-all-users</code>,'
-    ' only the IAM user that created the cluster can view and manage it. '
-    ' Clusters are visible by default.</p>')
+    '<p>Specifies whether the cluster is visible to all IAM users'
+    ' of the AWS account associated with the cluster. If a user'
+    ' has the proper policy permissions set, they can also manage the cluster.</p>'
+    '<p>Visibility is on by default. The <code>--no-visible-to-all-users</code> option'
+    ' is no longer supported. To restrict cluster visibility, use an IAM policy.</p>')
 
 DEBUGGING = (
     '<p>Specifies that the debugging tool is enabled for the cluster,'
     ' which allows you to browse log files using the Amazon EMR console.'
     ' Turning debugging on requires that you specify <code>--log-uri</code>'
     ' because log files must be stored in Amazon S3 so that'
-    ' Amazon EMR can index them for viewing in the console.</p>')
+    ' Amazon EMR can index them for viewing in the console.'
+    ' Effective January 23, 2023, Amazon EMR will discontinue the debugging tool for all versions.</p>')
 
 TAGS = (
     '<p>A list of tags to associate with a cluster, which apply to'
@@ -358,6 +368,17 @@ EBS_ROOT_VOLUME_SIZE = (
     ' in GiB, of the EBS root device volume of the Amazon Linux AMI'
     ' that is used for each EC2 instance in the cluster. </p>')
 
+EBS_ROOT_VOLUME_IOPS = (
+    '<p>This option is available only with Amazon EMR version 6.15.0 and later. Specifies the IOPS,'
+    ' of the EBS root device volume of the Amazon Linux AMI'
+    ' that is used for each EC2 instance in the cluster. </p>')
+
+EBS_ROOT_VOLUME_THROUGHPUT = (
+    '<p>This option is available only with Amazon EMR version 6.15.0 and later. Specifies the throughput,'
+    ' in MiB/s, of the EBS root device volume of the Amazon Linux AMI'
+    ' that is used for each EC2 instance in the cluster. </p>')
+
+
 SECURITY_CONFIG = (
     '<p>Specifies the name of a security configuration to use for the cluster.'
     ' A security configuration defines data encryption settings and'
@@ -400,7 +421,7 @@ KERBEROS_ATTRIBUTES = (
      ' with a KDC in a different realm. This is the cross-realm principal password,'
      ' which must be identical across realms.</li>'
      ' <li><code>ADDomainJoinUser</code> - Required when establishing trust with an Active Directory'
-     ' domain. This is the User logon name of an AD account with sufficient privileges to join resouces to the domain.</li>'
+     ' domain. This is the User logon name of an AD account with sufficient privileges to join resources to the domain.</li>'
      ' <li><code>ADDomainJoinPassword</code> - The AD password for <code>ADDomainJoinUser</code>.</li>')
 
 # end create-cluster options help descriptions
@@ -491,3 +512,13 @@ AUTO_TERMINATION_POLICY = (
     'The configuration specifies the termination idle timeout'
     'threshold for an cluster.</p> '
 )
+
+EXECUTION_ROLE_ARN = (
+    '<p>You must grant the execution role the permissions needed '
+    'to access the same IAM resources that the step can access. '
+    'The execution role can be a cross-account IAM Role.</p> '
+)
+
+UNHEALTHY_NODE_REPLACEMENT = (
+    '<p>Unhealthy node replacement for an Amazon EMR cluster.</p> '
+)
